#ifndef EFL_UI_VIEW_LIST_IMPL_HH
#define EFL_UI_VIEW_LIST_IMPL_HH

#include "efl_ui_view_list.eo.hh"

namespace efl { namespace ui { 
inline ::efl::eolian::return_traits< ::efl::ui::View_List_Relayout>::type View_List::relayout_get() const
{
    ::Efl_Ui_View_List_Relayout* __return_value =  ::efl_ui_view_list_relayout_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::ui::View_List_Relayout>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List::relayout_set( ::efl::eolian::in_traits< ::efl::ui::View_List_Relayout>::type object) const
{
    ::efl_ui_view_list_relayout_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Ui_View_List_Relayout*,  ::efl::eolian::in_traits< ::efl::ui::View_List_Relayout>::type>(object));
}
inline ::efl::eolian::return_traits<bool>::type View_List::homogeneous_get() const
{
   Eina_Bool __return_value =  ::efl_ui_view_list_homogeneous_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List::homogeneous_set( ::efl::eolian::in_traits<bool>::type homogeneous) const
{
    ::efl_ui_view_list_homogeneous_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(homogeneous));
}
inline ::efl::eolian::return_traits<Elm_Object_Select_Mode>::type View_List::select_mode_get() const
{
   Elm_Object_Select_Mode __return_value =  ::efl_ui_view_list_select_mode_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Object_Select_Mode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List::select_mode_set( ::efl::eolian::in_traits<Elm_Object_Select_Mode>::type mode) const
{
    ::efl_ui_view_list_select_mode_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Object_Select_Mode,  ::efl::eolian::in_traits<Elm_Object_Select_Mode>::type>(mode));
}
inline ::efl::eolian::return_traits< ::efl::eina::stringshare>::type View_List::default_style_get() const
{
   Eina_Stringshare * __return_value =  ::efl_ui_view_list_default_style_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::stringshare>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List::default_style_set( ::efl::eolian::in_traits< ::efl::eina::stringshare>::type style) const
{
    ::efl_ui_view_list_default_style_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Stringshare *,  ::efl::eolian::in_traits< ::efl::eina::stringshare>::type>(style));
}
inline ::efl::eolian::return_traits<void>::type View_List::layout_factory_set( ::efl::eolian::in_traits< ::efl::ui::Factory>::type factory) const
{
    ::efl_ui_view_list_layout_factory_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Ui_Factory*,  ::efl::eolian::in_traits< ::efl::ui::Factory>::type>(factory));
}
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits< ::efl::ui::View_List_Relayout>::type View_List::relayout_get() const
{
    ::Efl_Ui_View_List_Relayout* __return_value =  ::efl_ui_view_list_relayout_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::ui::View_List_Relayout>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List::relayout_set( ::efl::eolian::in_traits< ::efl::ui::View_List_Relayout>::type object) const
{
    ::efl_ui_view_list_relayout_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Ui_View_List_Relayout*,  ::efl::eolian::in_traits< ::efl::ui::View_List_Relayout>::type>(object));
}
inline ::efl::eolian::return_traits<bool>::type View_List::homogeneous_get() const
{
   Eina_Bool __return_value =  ::efl_ui_view_list_homogeneous_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List::homogeneous_set( ::efl::eolian::in_traits<bool>::type homogeneous) const
{
    ::efl_ui_view_list_homogeneous_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(homogeneous));
}
inline ::efl::eolian::return_traits<Elm_Object_Select_Mode>::type View_List::select_mode_get() const
{
   Elm_Object_Select_Mode __return_value =  ::efl_ui_view_list_select_mode_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Object_Select_Mode>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List::select_mode_set( ::efl::eolian::in_traits<Elm_Object_Select_Mode>::type mode) const
{
    ::efl_ui_view_list_select_mode_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Object_Select_Mode,  ::efl::eolian::in_traits<Elm_Object_Select_Mode>::type>(mode));
}
inline ::efl::eolian::return_traits< ::efl::eina::stringshare>::type View_List::default_style_get() const
{
   Eina_Stringshare * __return_value =  ::efl_ui_view_list_default_style_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::stringshare>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List::default_style_set( ::efl::eolian::in_traits< ::efl::eina::stringshare>::type style) const
{
    ::efl_ui_view_list_default_style_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Stringshare *,  ::efl::eolian::in_traits< ::efl::eina::stringshare>::type>(style));
}
inline ::efl::eolian::return_traits<void>::type View_List::layout_factory_set( ::efl::eolian::in_traits< ::efl::ui::Factory>::type factory) const
{
    ::efl_ui_view_list_layout_factory_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Ui_Factory*,  ::efl::eolian::in_traits< ::efl::ui::Factory>::type>(factory));
}
inline efl::ui::View_List::operator ::efl::ui::View_List() const { return *static_cast< ::efl::ui::View_List const*>(static_cast<void const*>(this)); }
inline efl::ui::View_List::operator ::efl::ui::View_List&() { return *static_cast< ::efl::ui::View_List*>(static_cast<void*>(this)); }
inline efl::ui::View_List::operator ::efl::ui::View_List const&() const { return *static_cast< ::efl::ui::View_List const*>(static_cast<void const*>(this)); }
} } }
#endif
